==> yuml-rs-0.1.0.crate: yuml-rs-0.1.0/README.md <==
# About

Rust based yUML parser based on the Javascript version from Jaime Olivares: [yuml-diagram](https://github.com/jaime-olivares/yuml-diagram).
At the moment only Activity diagrams are supported, with no guarantees that the other variations will be added in the future.

# Installation

This library depends on the "dot" binary being installed. It comes as part of the ["graphviz"](https://graphviz.org/download/) 
set of tools.

On a Mac you can install this with `brew install graphviz`. See the [graphviz page](https://graphviz.org/download/) for 
installation instructions for other operating systems.

## License

Licensed under:

* MIT license ([LICENSE-MIT](LICENSE-MIT) or
  [https://opensource.org/licenses/MIT](https://opensource.org/licenses/MIT))

## DISCLAIMER

Please note: all content in this repository is released for use "AS IS" without any warranties of any kind, including,
but not limited to their installation, use, or performance. We disclaim any and all warranties, either express or
implied, including but not limited to any warranty of noninfringement, merchantability, and/ or fitness for a particular
purpose. We do not warrant that the technology will meet your requirements, that the operation thereof will be
uninterrupted or error-free, or that any errors will be corrected.

Any use of this library is at your own risk. There is no guarantee that it has been through thorough testing in a
comparable environment and we are not responsible for any damage or data loss incurred with their use.

You are responsible for reviewing and testing any code you run thoroughly before use in any non-testing environment.

## About Avaya

Avaya elevates communications to the next generation of engagement, connecting organizations to their customers, workforce, and communities with secure, intelligent experiences that matter.

Check us out on: https://www.avaya.com

==> yuml-rs-0.1.4.crate: yuml-rs-0.1.4/README.md <==
# About

Rust based yUML parser based on the Javascript version from Jaime Olivares: [yuml-diagram](https://github.com/jaime-olivares/yuml-diagram).
At the moment only Activity and Class diagrams are supported, with no guarantees that the other variations will be added in the future.

# Installation

This library depends on the "dot" binary being installed. It comes as part of the ["graphviz"](https://graphviz.org/download/) 
set of tools.

On a Mac you can install this with `brew install graphviz`. See the [graphviz page](https://graphviz.org/download/) for 
installation instructions for other operating systems.

## License

Licensed under:

* MIT license ([LICENSE-MIT](LICENSE-MIT) or
  [https://opensource.org/licenses/MIT](https://opensource.org/licenses/MIT))

## DISCLAIMER

Please note: all content in this repository is released for use "AS IS" without any warranties of any kind, including,
but not limited to their installation, use, or performance. We disclaim any and all warranties, either express or
implied, including but not limited to any warranty of noninfringement, merchantability, and/ or fitness for a particular
purpose. We do not warrant that the technology will meet your requirements, that the operation thereof will be
uninterrupted or error-free, or that any errors will be corrected.

Any use of this library is at your own risk. There is no guarantee that it has been through thorough testing in a
comparable environment and we are not responsible for any damage or data loss incurred with their use.

You are responsible for reviewing and testing any code you run thoroughly before use in any non-testing environment.

## About Avaya

Avaya elevates communications to the next generation of engagement, connecting organizations to their customers, workforce, and communities with secure, intelligent experiences that matter.

Check us out on: https://www.avaya.com
